pype32.excep.ArrayTypeException

Package pype32 :: Module excep :: Class ArrayTypeException |
[hide private]
[frames] | no frames]

# Class ArrayTypeException

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                     PyPe32Exception --+
                                       |
                                      ArrayTypeException

Raised when creating an unsupported type of array.

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__init__`, `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`